@@ -221,6 +221,20 @@ games_card_textures_cache_new (void)
   return g_object_new (GAMES_TYPE_CARD_TEXTURES_CACHE, NULL);
 }
 
+/**
+ * games_card_textures_cache_drop:
+ * @images: a #GamesCardImages
+ *
+ * Clears the image cache.
+ */
+void
+games_card_textures_cache_drop (GamesCardTexturesCache *cache)
+{
+  g_return_if_fail (GAMES_IS_CARD_TEXTURES_CACHE (cache));
+
+  games_card_textures_cache_clear (cache);
+}
+
 /**
  * games_card_textures_cache_set_theme:
  * @cache:
